@@ -164,7 +164,7 @@ impl Loader for FetchCacher {
             Err(err)
           },
           |file| {
-            Ok(Some(LoadResponse {
+            Ok(Some(LoadResponse::Module {
               specifier: file.specifier,
               maybe_headers: file.maybe_headers,
               content: file.source,
@@ -288,11 +288,15 @@ impl Loader for MemoryCacher {
         specifier_str = specifier_str[3..].to_string();
       }
     }
-    let response = self.sources.get(&specifier_str).map(|c| LoadResponse {
-      specifier: specifier.clone(),
-      maybe_headers: None,
-      content: c.to_owned(),
-    });
+    let response =
+      self
+        .sources
+        .get(&specifier_str)
+        .map(|c| LoadResponse::Module {
+          specifier: specifier.clone(),
+          maybe_headers: None,
+          content: c.to_owned(),
+        });
     Box::pin(future::ready(Ok(response)))
   }
 }
