@@ -25,6 +25,7 @@ use deno_core::ModuleSpecifier;
 use deno_core::OpFn;
 use deno_core::RuntimeOptions;
 use deno_core::Snapshot;
+use deno_graph::Resolved;
 use once_cell::sync::Lazy;
 use std::collections::HashMap;
 use std::path::PathBuf;
@@ -529,8 +530,12 @@ fn op_resolve(state: &mut State, args: ResolveArgs) -> Result<Value, AnyError> {
       let referrer = graph_data.follow_redirect(&referrer);
       let resolved_dep = match graph_data.get(&referrer) {
         Some(ModuleEntry::Module { dependencies, .. }) => {
-          dependencies.get(specifier).and_then(|d| {
-            d.maybe_type.as_ref().or_else(|| d.maybe_code.as_ref())
+          dependencies.get(specifier).map(|d| {
+            if matches!(d.maybe_type, Resolved::Ok { .. }) {
+              &d.maybe_type
+            } else {
+              &d.maybe_code
+            }
           })
         }
         Some(ModuleEntry::Configuration { dependencies }) => {
@@ -539,7 +544,7 @@ fn op_resolve(state: &mut State, args: ResolveArgs) -> Result<Value, AnyError> {
         _ => None,
       };
       let maybe_result = match resolved_dep {
-        Some(Ok((specifier, _))) => {
+        Some(Resolved::Ok { specifier, .. }) => {
           let specifier = graph_data.follow_redirect(specifier);
           match graph_data.get(&specifier) {
             Some(ModuleEntry::Module {
@@ -547,8 +552,8 @@ fn op_resolve(state: &mut State, args: ResolveArgs) -> Result<Value, AnyError> {
               maybe_types,
               ..
             }) => match maybe_types {
-              Some(Ok((types, _))) => {
-                let types = graph_data.follow_redirect(types);
+              Some(Resolved::Ok { specifier, .. }) => {
+                let types = graph_data.follow_redirect(specifier);
                 match graph_data.get(&types) {
                   Some(ModuleEntry::Module { media_type, .. }) => {
                     Some((types, media_type))
@@ -714,6 +719,7 @@ mod tests {
   use crate::diagnostics::DiagnosticCategory;
   use crate::emit::Stats;
   use deno_core::futures::future;
+  use deno_graph::ModuleKind;
   use std::fs;
 
   #[derive(Debug, Default)]
@@ -735,7 +741,7 @@ mod tests {
       let source_path = self.fixtures.join(specifier_text);
       let response = fs::read_to_string(&source_path)
         .map(|c| {
-          Some(deno_graph::source::LoadResponse {
+          Some(deno_graph::source::LoadResponse::Module {
             specifier: specifier.clone(),
             maybe_headers: None,
             content: Arc::new(c),
@@ -757,7 +763,7 @@ mod tests {
     let fixtures = test_util::testdata_path().join("tsc2");
     let mut loader = MockLoader { fixtures };
     let graph = deno_graph::create_graph(
-      vec![specifier],
+      vec![(specifier, ModuleKind::Esm)],
       false,
       None,
       &mut loader,
@@ -784,7 +790,7 @@ mod tests {
     let fixtures = test_util::testdata_path().join("tsc2");
     let mut loader = MockLoader { fixtures };
     let graph = deno_graph::create_graph(
-      vec![specifier.clone()],
+      vec![(specifier.clone(), ModuleKind::Esm)],
       false,
       None,
       &mut loader,
